##############################################################
# Replication File for                                       #
# Juhl et al.                                                #
# Preferences for Centralized Decision-Making in Times of    #
# Crisis: The COVID-19 Pandemic in Germany                   #
# Jahrbuch fr Handlungs- und Entscheidungstheorie           #
# 2021                                                       #
# by Roni Lehrer 4th May 2020                                #
##############################################################

#Information on R version and package version are at the very bottom of this script.

##########################################################################
# THIS ANALYSIS REQUIRES FULL MCS DATA, I.E. NOT VERSION STORED AT GESIS #
# In particular, the age variable as respondents' place of residence are #
# not included in the GESIS version. The full dataset can be accessed    #
# at the German Internet Panel Offices at the University of Mannheim.    #
##########################################################################

rm(list=ls())
library(data.table)
library(readstata13)
library(haven)
library(nomclust)
library(lme4)
library(stargazer)
library(MASS)
library(ggplot2)

Sys.setenv("LANGUAGE"="En")
Sys.setlocale("LC_ALL", "English")

weighted.proportion2 <- function(x, weights=NULL){
  # if no weights are supplied: calculate unweighted proportion
  if(is.null(weights)){
    weights <- 1/length(x)
  }
  # remove obs with missing weights
  if(anyNA(weights)){
    miss <- is.na(weights)
    weights <- weights[!miss]
    x <- x[!miss]
  }
  # stop if x is not binary
  if(!all(unique(x[!is.na(x)]) %in% c(0,1))) stop("x must contain only 0, 1 (or NA)")
  # calculate weighted SE of proportions
  st.w <- weights/sum(weights)
  prop.x <- sum(st.w*x, na.rm=T)
  se.x <- sqrt(prop.x*(1-prop.x)*sum(st.w[!is.na(x)]^2))
  return(prop.x)
}

###################################
# Prepare Containment Policy Data #
###################################

#Measure data: https://doi.org/10.23668/PSYCHARCHIVES.3486
measures <- fread("ZPID lockdown measures dataset 3.0.csv")
measures <- melt(measures, id.vars=c("stateID", "state", "Measure"))
measures <- dcast(measures, stateID+state+variable~Measure, value.var="value")
measures$land <- ifelse(measures$state=="Schleswig-Holstein", "01",
                        ifelse(measures$state=="Hamburg", "02",
                               ifelse(measures$state=="Niedersachsen", "03",
                                      ifelse(measures$state=="Bremen", "04",
                                             ifelse(measures$state=="Nordrhein-Westfalen", "05",
                                                    ifelse(measures$state=="Hessen",  "06",
                                                           ifelse(measures$state=="Rheinland-Pfalz", "07",
                                                                  ifelse(measures$state=="Baden-Wuerttemberg", "08",
                                                                         ifelse(measures$state=="Bayern", "09",
                                                                                ifelse(measures$state=="Saarland", "10",
                                                                                       ifelse(measures$state=="Berlin", "11",
                                                                                              ifelse(measures$state=="Brandenburg", "12",
                                                                                                     ifelse(measures$state=="Mecklenburg-Vorpommern", "13",
                                                                                                            ifelse(measures$state=="Sachsen", "14",
                                                                                                                   ifelse(measures$state=="Sachsen-Anhalt", "15",
                                                                                                                          ifelse(measures$state=="Thueringen", "16", ""))))))))))))))))
measures$date <- as.Date(measures$variable)

#mean difference each day between all states
mean.differences <- data.table(date=NA, mean.differences=NA)
out <- data.table(date=NA, mean.differences=NA)
for (i in unique(as.character(measures$date))) {
  matching <- sm(measures[date==i,list(church, daycare, demo, dist, ess_shps,
                                       hcut, leavehome, morefriends, msk, onefriend, plygrnd, school, shppng, zoo)])
  matching <- as.matrix(matching)
  diag(matching) <- NA
  out$mean.differences <- mean(matching, na.rm=TRUE)
  out$date <- i
  mean.differences <- rbindlist(list(mean.differences, out))
}
mean.differences$date <- as.Date(mean.differences$date)
measures <- merge(measures, mean.differences, all.x=TRUE, by="date")

measures <- measures[,list(land, date, leavehome, daycare, school, mean.differences)]
setnames(measures, "leavehome", "measure.leavehome")
setnames(measures, "daycare", "measure.daycare")
setnames(measures, "school", "measure.school")

#load MCS data
file_path <- "GIP-SC-Long-Weights.dta"
dat <- as.data.table(read_dta(file_path))
dat <- dat[Teilnahme==1]
dat$date <- as.Date(paste0("2020-", dat$dMonth, "-", dat$dDay))

#get data that links respondents' ZIP code to states
load("plz.Rdata")

#get Kreis from plz data
dat$SCDX002 <- as.character(formatC(dat$SCDX002, width = 5, format = "d", flag = "0"))
dat <- merge(dat, plz, by.x="SCDX002", by.y="plz", all.x=TRUE)

#get RKI data: Official statistics about confirmed COVID-19 infections
load("rki.daily.pop.Rdata")

#delete cases we don't need
rki.daily <- rki.daily[,list(kreis, date, last7days.cases.land)]

#get cases from RKI data (based on response date)
#Das passiert drei Mal, weil es bis zu drei Kreisen gibt, die rangemergt werden knnen.
dat <- merge(dat, rki.daily, all.x=TRUE, by.x=c("kreis_1", "date"), by.y=c("kreis", "date"))
setnames(dat, "last7days.cases.land", "last7days.cases.land1")
dat <- merge(dat, rki.daily, all.x=TRUE, by.x=c("kreis_2", "date"), by.y=c("kreis", "date"))
setnames(dat, "last7days.cases.land", "last7days.cases.land2")
dat <- merge(dat, rki.daily, all.x=TRUE, by.x=c("kreis_3", "date"), by.y=c("kreis", "date"))
setnames(dat, "last7days.cases.land", "last7days.cases.land3")

#get average values across all potential Landkreise
dat <- dat[,n:=1:.N]
dat <- dat[,last7days.cases.land:=mean(c(last7days.cases.land1, last7days.cases.land2, last7days.cases.land3), na.rm=TRUE), n]
dat$n <- NULL

#rescale to ease computation later on
dat$last7days.cases.land   <- scale(dat$last7days.cases.land)

dat$land <- substring(dat$kreis_1, 1, 2)


#merge with measures data
dat <- merge(dat, measures, by=c("land", "date"))


dat$threat <- ifelse(dat$SCBX003<0, NA, dat$SCBX003)

dat$female <- ifelse(dat$gender_19<0, NA,
                     ifelse(dat$gender_19==2, 1, 0))

dat$age <- ifelse(dat$year_of_birth<0, NA, 2020-dat$year_of_birth)

dat$educ <- ifelse(dat$educ_school_19<0|dat$educ_school_19==7, NA,
                   ifelse(dat$educ_school_19>=5, 3,
                          ifelse(dat$educ_school_19==4, 2, 1)))
dat$educ <- factor(dat$educ, levels=1:3, labels=c("niedrig", "mittel", "hoch"))

dat$hh.incom.prev.month <- ifelse(dat$Woche%in%c(1,2), dat$SCDX001,
                                  ifelse(dat$Woche%in%c(3,4,5,6), dat$SCDX005,
                                         ifelse(dat$Woche%in%c(7.8,9,10,11), dat$SCDX007,
                                                ifelse(dat$Woche%in%c(12,13,14,15), dat$SCDX008, dat$SCDX009))))

dat$hh.incom.prev.month <-  ifelse(dat$hh.incom.prev.month<0, NA,
                                   ifelse(dat$hh.incom.prev.month==1, 150,
                                          ifelse(dat$hh.incom.prev.month==2, 400,
                                                 ifelse(dat$hh.incom.prev.month>2&dat$hh.incom.prev.month<15,
                                                        (dat$hh.incom.prev.month*500)-500, 7500))))

dat$number_hh_members_19 <- ifelse(dat$number_hh_members_19<0, NA, dat$number_hh_members_19)

dat$hh.incom.prev.month.pc <-  dat$hh.incom.prev.month/dat$number_hh_members_19
dat$hh.incom.prev.month.pc.cat <- factor(ifelse(is.na(dat$hh.incom.prev.month.pc), NA,
                                                ifelse(dat$hh.incom.prev.month.pc<1000, 1,
                                                       ifelse(dat$hh.incom.prev.month.pc<2500, 2, 3))),
                                         labels=c("<1k", "1-2.5k", ">2.5k"), levels=1:3)

dat$empower <- ifelse(dat$SCPX004<0, NA, dat$SCPX004-1)

################
# Trust in Gov #
################
gip <- as.data.table(read.dta13("GIP_W45_V1.dta"))
gip <- gip[,list(id_g, AK45034)]
dat <- merge(dat, gip, by="id_g", all.x=TRUE)
dat$gov.trust.jan <- ifelse(dat$AK45034<0, NA, dat$AK45034-1)

dat$sat.gov <- ifelse(dat$CE44152<0, NA, dat$CE44152-1)

gip <- as.data.table(read.dta13("GIP_W44_V1.dta"))
gip <- gip[,list(id_g, CE44153, CE44154, CE44155, CE44156, CE44312, CE44313)]
dat <- merge(dat, gip, by="id_g", all.x=TRUE)
dat$sat.union <- ifelse(dat$CE44153<0, NA, dat$CE44153-1)
dat$sat.spd <- ifelse(dat$CE44154<0, NA, dat$CE44154-1)
dat$sat.gr <- ifelse(dat$CE44155<0, NA, dat$CE44155-1)
dat$sat.lin <- ifelse(dat$CE44156<0, NA, dat$CE44156-1)
dat$sat.afd <- ifelse(dat$CE44312<0, NA, dat$CE44312-1)
dat$sat.fdp <- ifelse(dat$CE44313<0, NA, dat$CE44313-1)

dat <- dat[,sat.parl.max:=max(sat.union, sat.spd, sat.gr, sat.lin, sat.afd, sat.fdp, na.rm=TRUE), id_g]
dat$sat.parl.max <- ifelse(is.infinite(dat$sat.parl.max), NA, dat$sat.parl.max)

dat$LR <- ifelse(dat$AA43040a<0, NA, dat$AA43040a-1)
dat$LR2 <- dat$LR*dat$LR

dat <- dat[,list(id_g, Woche, land, wi_rake, empower,
                 last7days.cases.land, mean.differences,
                sat.gov, sat.parl.max, gov.trust.jan,
                 threat, female, educ, hh.incom.prev.month.pc.cat, LR, LR2, age)]


#Weighted correlation between gov.trust and sat.gov
cov.sub <- unique(na.omit(dat[,list(id_g, gov.trust.jan, sat.gov, wi_rake)]))
cov.wt(cov.sub[,list(gov.trust.jan, sat.gov)], wt=cov.sub$wi_rake, cor=TRUE)$cor

#Weighted correlation between AfD support and parliament support
cov.sub <- unique(na.omit(dat[,list(id_g, sat.parl.max, AfDvote, wi_rake)]))
cov.wt(cov.sub[,list(sat.parl.max, AfDvote)], wt=cov.sub$wi_rake, cor=TRUE)$cor

model6 <- lmer(empower~
                 mean.differences
               +sat.gov
               +sat.parl.max
               +gov.trust.jan
               +threat
               #+(1|land/id_g),
               +(1|id_g),
               data=dat, weights=wi_rake)

model7 <- lmer(empower~
                 mean.differences
               +sat.gov
               +sat.parl.max
               +gov.trust.jan
               +threat
               +last7days.cases.land
               +female
               +as.factor(educ)
               +as.factor(hh.incom.prev.month.pc.cat)
               +LR
               +LR2
               +age
               +(1|id_g),
               #+(1|id_g),
               data=dat, weights=wi_rake)

stargazer(model6, model7,
          header=FALSE,
          model.numbers= FALSE,
          type='latex',
          no.space=TRUE,
          dep.var.caption="",
          omit.stat = c("aic", "bic"),
          dep.var.labels = c(""),
          order = c(1, 4, 2, 3, 5, 6, 14, 7, 8:13),
          covariate.labels = c("Policy Heterogeneity",
                               "Trust in Government (Pre-Pandemic)",
                               "Satisfaction with Federal Government",
                               "Satisfaction with Parliament",
                               "COVID-19 Threat",
                               "COVID-19 Incidence",
                               "Age",
                               "Female",
                               "Education: Medium",
                               "Education: High",
                               "HH Income Previous Month: Medium",
                               "HH Income Previous Month: High",
                               "LR-Placement",
                               "LR-Placement$^2$",
                               "Constant"),
          label="tab:regressions",
          title="Regression Analyses",
          add.lines = c(list(c("Random Effects (Standard Deviations)","", ""),
                             c("Respondents",
                               round(attributes(VarCorr(model6)$"id_g")$stddev,3),
                               round(attributes(VarCorr(model7)$"id_g")$stddev,3)),
                             "\\hline"
          )))


set.seed(2387)
betas7 <- mvrnorm(1000, fixef(model7), vcov(model7))

###########################
# plot policy differences #
###########################

counter <- as.data.table(expand.grid(
  intercept=0,
  mean.differences=seq(min(dat$mean.differences, na.rm=TRUE), max(dat$mean.differences, na.rm=TRUE), length.out=50),
  sat.gov=0,
  sat.parl.max=0,
  gov.trust.jan=0,
  threat=0,
  last7days.cases.land=0,
  female=0,
  educ2=0,
  educ3=0,
  hh.incom.prev.month.pc.catupto2500=0,
  hh.incom.prev.month.pc.catmorethan2500=0,
  LR=0,
  LR2=0,
  age=0))
linpred <- as.matrix(counter)%*%t(betas7)
counter$lower <- apply(linpred, 1, quantile, p=.025)
counter$upper <- apply(linpred, 1, quantile, p=.975)
counter$mean <- apply(linpred, 1, mean)
counter$var <- "mean.differences"
counter$x <- counter$mean.differences
counter$model <- 1
counter <- counter[,list(var, x, lower, upper, mean, model)]

p <- ggplot(data=counter)
p <- p + geom_ribbon(aes(ymin=lower, ymax=upper, x=x), fill="grey80")
p <- p + geom_line(aes(y=mean, x=x), color="black")
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = "none",
               text=element_text(size = 17))
p <- p + xlab("Policy Heterogeneity")
p <- p + ylab("Marginal Effect on\nApproval of Decison-Making Centralization")
p
ggsave("policy_difference.pdf")

counter <- as.data.table(expand.grid(
  intercept=0,
  mean.differences=0,
  sat.gov=0:10,
  sat.parl.max=0,
  gov.trust.jan=0,
  threat=0,
  last7days.cases.land=0,
  female=0,
  educ2=0,
  educ3=0,
  hh.incom.prev.month.pc.catupto2500=0,
  hh.incom.prev.month.pc.catmorethan2500=0,
  LR=0,
  LR2=0,
  age=0))
linpred <- as.matrix(counter)%*%t(betas7)
counter$lower <- apply(linpred, 1, quantile, p=.025)
counter$upper <- apply(linpred, 1, quantile, p=.975)
counter$mean <- apply(linpred, 1, mean)
counter$x <- counter$sat.gov
counter$model <- 1
counter <- counter[,list(var, x, lower, upper, mean, model)]

counter$type <- "Federal Government"
pdata <- counter

p <- ggplot(data=counter)
p <- p + geom_segment(aes(y=lower, yend=upper, x=x, xend=x))
p <- p + geom_point(aes(y=mean, x=x), color="black")
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = "none",
               text=element_text(size = 17))
p <- p + xlab("Satisfaction with Federal Government")
p <- p + ylab("Marginal Effect on\nApproval of Decison-Making Centralization")
p <- p + ylim(c(-1, 1))
p
ggsave("sat_gov.pdf")

################
# plot sat.parl #
################


counter <- as.data.table(expand.grid(
  intercept=0,
  mean.differences=0,
  sat.gov=0,
  sat.parl.max=0:10,
  gov.trust.jan=0,
  threat=0,
  last7days.cases.land=0,
  female=0,
  educ2=0,
  educ3=0,
  hh.incom.prev.month.pc.catupto2500=0,
  hh.incom.prev.month.pc.catmorethan2500=0,
  LR=0,
  LR2=0,
  age=0))
linpred <- as.matrix(counter)%*%t(betas7)
counter$lower <- apply(linpred, 1, quantile, p=.025)
counter$upper <- apply(linpred, 1, quantile, p=.975)
counter$mean <- apply(linpred, 1, mean)
counter$x <- counter$sat.parl.max
counter$model <- 1
counter <- counter[,list(var, x, lower, upper, mean, model)]
counter$type <- "Parliament"
pdata <- rbindlist(list(pdata, counter))



pdata$x <- ifelse(pdata$type=="Federal Government", pdata$x-.1, pdata$x+.1)

p <- ggplot(data=pdata, aes(group=as.factor(type)))
p <- p + geom_hline(yintercept=0)
p <- p + geom_segment(aes(y=lower, yend=upper, x=x, xend=x))
p <- p + geom_point(aes(y=mean, x=x, shape=as.factor(type)), size=3, color="black")
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = c(.15,.88),
               legend.title=element_blank(),
               text=element_text(size = 17))
p <- p + scale_x_continuous("Satisfaction with Federal Government and Parliament", breaks=c(0, 2, 4, 6, 8, 10))
p <- p + ylab("Marginal Effect on\nApproval of Decison-Making Centralization")
p <- p + ylim(c(-1, 1))
ggsave("sat_both.pdf")

###############
# plot threat #
###############


counter <- as.data.table(expand.grid(
  intercept=0,
  mean.differences=0,
  sat.gov=0,
  sat.parl.max=0,
  gov.trust.jan=0,
  threat=0:10,
  last7days.cases.land=0,
  female=0,
  educ2=0,
  educ3=0,
  hh.incom.prev.month.pc.catupto2500=0,
  hh.incom.prev.month.pc.catmorethan2500=0,
  LR=0,
  LR2=0,
  age=0))
linpred <- as.matrix(counter)%*%t(betas7)
counter$lower <- apply(linpred, 1, quantile, p=.025)
counter$upper <- apply(linpred, 1, quantile, p=.975)
counter$mean <- apply(linpred, 1, mean)
counter$x <- counter$threat
counter$model <- 1
counter <- counter[,list(var, x, lower, upper, mean, model)]

p <- ggplot(data=counter)
p <- p + geom_segment(aes(y=lower, yend=upper, x=x, xend=x))
p <- p + geom_point(aes(y=mean, x=x), color="black")
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = "none",
               text=element_text(size = 17))
p <- p + scale_x_continuous("Perceived COVID-19 Threat", breaks=c(0, 2, 4, 6, 8, 10))
p <- p + ylab("Marginal Effect on\nApproval of Decison-Making Centralization")
p
ggsave("threat.pdf")


#####################################
# Counterfactual Shares of Approval #
#####################################

pdata <- data.table(x=NA, proportion=NA, upper=NA, lower=NA)

#these are the intercepts for each individual (not the differences from the average intercept)
intercepts <- data.table(ranef=coef(model7)$id_g[,1],
                         id_g=as.numeric(rownames(coef(model7)$id_g)))
intercepts <- intercepts[,mean.ranef:=mean(ranef)]
intercepts$ranef.dif.from.mean <- intercepts$ranef-intercepts$mean.ranef


for (i in seq(0, 0.2613095, length.out=50)) {
  print(i)
  counter <- data.table(
    id_g=dat$id_g,
    wi_rake=dat$wi_rake,
    mean.differences=i,
    sat.gov=dat$sat.gov,
    sat.parl.max=dat$sat.parl.max,
    gov.trust.jan=dat$gov.trust.jan,
    threat=dat$threat,
    last7days.cases.land=dat$last7days.cases.land,
    female=dat$female,
    educ2=ifelse(dat$educ=="mittel", 1, 0),
    educ3=ifelse(dat$educ=="hoch", 1, 0),
    hh.incom.prev.month.pc.catupto2500=ifelse(dat$hh.incom.prev.month.pc.cat=="1-2.5k", 1, 0),
    hh.incom.prev.month.pc.catmorethan2500=ifelse(dat$hh.incom.prev.month.pc.cat==">2.5k", 1, 0),
    LR=dat$LR,
    LR2=dat$LR2,
    age=dat$age)
  counter <- merge(counter, intercepts, by="id_g", all.x=TRUE)
  counter <- na.omit(counter)
  counter$intercept <- 1 #make sure to get both overall intercept and RE deviation
  coefs <- rbind(1, t(as.matrix(betas7))) #make sure to get both overall intercept and RE deviation
  linpred <- as.matrix(counter[,list(ranef.dif.from.mean, intercept, mean.differences, sat.gov, sat.parl.max, gov.trust.jan,
                                             threat, last7days.cases.land, female, educ2, educ3,
                                             hh.incom.prev.month.pc.catupto2500, hh.incom.prev.month.pc.catmorethan2500,
                                             LR, LR2, age)])%*%coefs
  linpred <- ifelse(linpred>3, 1, 0)
  props <- apply(linpred, 2, weighted.proportion2, weights=counter$wi_rake)
  prop.mean <- mean(props)
  upper <- quantile(props, probs=.975)
  lower <- quantile(props, probs=.025)
  pdata <- rbindlist(list(pdata, data.table(x=i, proportion=prop.mean, upper=upper, lower=lower)))
}
pdata <- na.omit(pdata)
pdata$proportion <- pdata$proportion*100
pdata$upper <- pdata$upper*100
pdata$lower <- pdata$lower*100

p <- ggplot(data=pdata)
p <- p + geom_ribbon(aes(ymin=lower, ymax=upper, x=x), fill="grey80")
p <- p + geom_line(aes(y=proportion, x=x), color="black")
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = "none",
               text=element_text(size = 17))
p <- p + scale_x_continuous("Policy Heterogeneity", breaks=seq(0, .3, .05))
p <- p + ylab("Predicted Percentage of Respondents\nApproving Decision-Making Centralization")
p
ggsave("shares.pdf")



measures.plot <- measures[land==11, list(date, mean.differences)]
p <- ggplot(data=measures.plot, aes(x=date, y=mean.differences))
p <- p + geom_hline(aes(yintercept=.085), color="grey")
p  <- p +  geom_rect(aes(xmin=as.Date("2020-03-20"),xmax=as.Date("2020-07-10"),
                         ymin=-Inf,ymax=Inf),alpha=0.05, fill="grey90")
p <- p + geom_line()
p <- p + theme_bw()
p <- p + theme(panel.grid.major.x = element_blank(),
               panel.grid.minor = element_blank(),
               plot.caption=element_text(hjust=0),
               #axis.title=element_text(size=19, color="grey15"),
               #axis.text = element_text(size=19, color="grey15"),
               axis.ticks = element_line(color="grey"),
               legend.position = "none",
               text=element_text(size = 17))
p <- p + scale_x_date("", date_breaks = "1 month", date_labels =  "%b")
p <- p + ylab("COVID???19 Policy Heterogeneity")
p
ggsave("measures.pdf")

###################################################
# Models with Alternative Random-Effect Structure #
###################################################

model6 <- lmer(empower~
                 mean.differences
               +sat.gov
               +sat.parl.max
               +gov.trust.jan
               +threat
               #+(1|land/id_g),
               +(1|land/id_g),
               data=dat, weights=wi_rake)

model7 <- lmer(empower~
                 mean.differences
               +sat.gov
               +sat.parl.max
               +gov.trust.jan
               +threat
               +last7days.cases.land
               +female
               +as.factor(educ)
               +as.factor(hh.incom.prev.month.pc.cat)
               +LR
               +LR2
               +age
               +(1|land/id_g),
               #+(1|id_g),
               data=dat, weights=wi_rake)

stargazer(model6, model7,
          header=FALSE,
          model.numbers= FALSE,
          type='latex',
          no.space=TRUE,
          dep.var.caption="",
          omit.stat = c("aic", "bic"),
          dep.var.labels = c(""),
          order = c(1, 4, 2, 3, 5, 6, 14, 7, 8:13),
          covariate.labels = c("Policy Heterogeneity",
                               "Trust in Government (Pre-Pandemic)",
                               "Satisfaction with Federal Government",
                               "Satisfaction with Parliament",
                               "COVID-19 Threat",
                               "COVID-19 Incidence",
                               "Age",
                               "Female",
                               "Education: Medium",
                               "Education: High",
                               "HH Income Previous Month: Medium",
                               "HH Income Previous Month: High",
                               "LR-Placement",
                               "LR-Placement$^2$",
                               "Constant"),
          label="tab:regressions2",
          title="Regression Analyses with Alternative Random-Effects Structure",
          add.lines = c(list(c("Random Effects (Standard Deviations)","", ""),
                             c("State",
                               round(attributes(VarCorr(model6)$"land")$stddev,3),
                               round(attributes(VarCorr(model7)$"land")$stddev,3)),
                             c("Respondents nested in State",
                               round(attributes(VarCorr(model6)$"id_g:land")$stddev,3),
                               round(attributes(VarCorr(model7)$"id_g:land")$stddev,3)),
                             "\\hline"
          )))




###############################
# weighted summary statistics #
###############################

sub <- na.omit(dat[,list(empower, mean.differences, sat.gov, sat.parl.max, gov.trust.jan,
                         threat, last7days.cases.land, female, educ, hh.incom.prev.month.pc.cat,
                         LR, LR2, age)])
sub$educ.mittel <- ifelse(sub$educ=="mittel", 1, 0)
sub$educ.hoch <- ifelse(sub$educ=="hoch", 1, 0)
sub$income.mittel <- ifelse(sub$hh.incom.prev.month.pc.cat=="1-2.5k", 1, 0)
sub$income.hoch <- ifelse(sub$hh.incom.prev.month.pc.cat==">2.5k", 1, 0)


stargazer(sub,
          summary.stat = c("n", "mean", "sd", "min", "max"),
          covariate.labels = c("Decision-Making Centralization",
                               "Policy Heterogeneity",
                               "Satisfaction with Federal Government",
                               "Satisfaction with Parliament",
                               "Trust in Government (Pre-Pandemic)",
                               "COVID-19 Threat",
                               "COVID-19 Incidence",
                               "Female",
                               "LR-Placement",
                               "LR-Placement$^2$",
                               "Age",
                               "Education: Medium",
                               "Education: High",
                               "HH Income Previous Month: Medium",
                               "HH Income Previous Month: High")
)



# R version 4.0.2 (2020-06-22)
# Platform: x86_64-w64-mingw32/x64 (64-bit)
# Running under: Windows 10 x64 (build 18362)
#
# Matrix products: default
#
# locale:
#   [1] LC_COLLATE=English_United States.1252  LC_CTYPE=English_United States.1252    LC_MONETARY=English_United States.1252
# [4] LC_NUMERIC=C                           LC_TIME=English_United States.1252
#
# attached base packages:
#   [1] stats     graphics  grDevices utils     datasets  methods   base
#
# other attached packages:
#   [1] ggplot2_3.3.3     MASS_7.3-53.1     stargazer_5.2.2   lme4_1.1-26       Matrix_1.2-18     nomclust_2.2.1    plyr_1.8.6
# [8] cluster_2.1.2     haven_2.4.1       readstata13_0.9.2 data.table_1.14.0
#
# loaded via a namespace (and not attached):
#   [1] Rcpp_1.0.6       pillar_1.6.0     compiler_4.0.2   nloptr_1.2.2.2   forcats_0.5.1    tools_4.0.2      digest_0.6.27
# [8] boot_1.3-27      statmod_1.4.35   lifecycle_1.0.0  tibble_3.1.1     nlme_3.1-152     gtable_0.3.0     lattice_0.20-41
# [15] pkgconfig_2.0.3  rlang_0.4.10     DBI_1.1.1        withr_2.4.2      dplyr_1.0.5      generics_0.1.0   vctrs_0.3.7
# [22] hms_1.0.0        tidyselect_1.1.0 grid_4.0.2       glue_1.4.2       R6_2.5.0         fansi_0.4.2      minqa_1.2.4
# [29] farver_2.1.0     readr_1.4.0      purrr_0.3.4      magrittr_2.0.1   scales_1.1.1     ellipsis_0.3.1   splines_4.0.2
# [36] assertthat_0.2.1 colorspace_2.0-0 labeling_0.4.2   utf8_1.2.1       munsell_0.5.0    crayon_1.4.1
